@@ -21,8 +21,7 @@
 #include "ggit-branch.h"
 #include "ggit-error.h"
 
-#include <git2/branch.h>
-#include <git2/errors.h>
+#include <git2.h>
 
 
 G_DEFINE_TYPE (GgitBranch, ggit_branch, GGIT_TYPE_REF)
