@@ -674,19 +674,26 @@ typedef struct
 	GRegex *regex;
 	GMatchInfo *ret;
 
-	const gchar *value;
+	gchar *value;
 
 	GgitConfigMatchCallback callback;
 	gpointer user_data;
 } MatchInfo;
 
 static gint
-match_foreach (const gchar *name,
-               const gchar *value,
-               MatchInfo   *info)
+match_foreach (GgitConfigEntry *entry,
+               MatchInfo       *info)
 {
+	const gchar *name;
+
+	name = ggit_config_entry_get_name (entry);
+
 	if (g_regex_match (info->regex, name, (GRegexMatchFlags)0, &info->ret))
 	{
+		const gchar *value;
+
+		value = ggit_config_entry_get_value (entry);
+
 		if (info->callback)
 		{
 			gint ret;
@@ -698,7 +705,8 @@ match_foreach (const gchar *name,
 		}
 		else
 		{
-			info->value = value;
+			g_free (info->value);
+			info->value = g_strdup (value);
 
 			/* Semi arbitrary error */
 			return GGIT_ERROR_EXISTS;
@@ -719,10 +727,10 @@ match_foreach (const gchar *name,
  * contain the match information if the return value is not %NULL, otherwise
  * @error will be set.
  *
- * Returns: (allow-none): the value of that matched configuration
+ * Returns: (allow-none) (transfer full): the value of that matched configuration
  *
  **/
-const gchar *
+gchar *
 ggit_config_match (GgitConfig  *config,
                    GRegex      *regex,
                    GMatchInfo **match_info,
