@@ -956,6 +956,29 @@ ggit_attribute_check_flags_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_packbuilder_stage_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_PACKBUILDER_STAGE_ADDING_OBJECTS,
+			  "GGIT_PACKBUILDER_STAGE_ADDING_OBJECTS",
+			  "adding-objects" },
+			{ GGIT_PACKBUILDER_STAGE_DELTAFICATION,
+			  "GGIT_PACKBUILDER_STAGE_DELTAFICATION",
+			  "deltafication" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitPackbuilderStage"),
+				values);
+	}
+	return the_type;
+}
+
 
 /* Generated data ends here */
 
