@@ -16,6 +16,9 @@ GType ggit_branch_type_get_type	(void) G_GNUC_CONST;
 #define GGIT_TYPE_CAP_FLAGS	(ggit_cap_flags_get_type())
 GType ggit_cap_flags_get_type	(void) G_GNUC_CONST;
 
+#define GGIT_TYPE_BLAME_FLAGS	(ggit_blame_flags_get_type())
+GType ggit_blame_flags_get_type	(void) G_GNUC_CONST;
+
 #define GGIT_TYPE_CONFIG_LEVEL	(ggit_config_level_get_type())
 GType ggit_config_level_get_type	(void) G_GNUC_CONST;
 
@@ -88,6 +91,12 @@ GType ggit_status_option_get_type	(void) G_GNUC_CONST;
 #define GGIT_TYPE_STATUS_SHOW	(ggit_status_show_get_type())
 GType ggit_status_show_get_type	(void) G_GNUC_CONST;
 
+#define GGIT_TYPE_ATTRIBUTE_CHECK_FLAGS	(ggit_attribute_check_flags_get_type())
+GType ggit_attribute_check_flags_get_type	(void) G_GNUC_CONST;
+
+#define GGIT_TYPE_PACKBUILDER_STAGE	(ggit_packbuilder_stage_get_type())
+GType ggit_packbuilder_stage_get_type	(void) G_GNUC_CONST;
+
 G_END_DECLS
 
 #endif /* __GGIT_ENUM_TYPES_H__ */
