@@ -50,6 +50,30 @@ _ggit_ref_wrap (git_reference *ref)
 	                     NULL);
 }
 
+/**
+ * ggit_ref_is_valid_name:
+ * @name: the name to validate.
+ *
+ * Check if the given @name is a valid name for a reference. Note that @name
+ * should be the full ref name (including prefixes).
+ *
+ * Valid toplevel names can contain only capital letters and underscores
+ * and must start and end with a letter (e.g. HEAD, ORIG_HEAD).
+ *
+ * Valid refs/ names may contain any characters, except '~', '^', ':', '\', '?',
+ * '[', '*', ".." and "@{", because they are interpreted by revparse.
+ *
+ * Returns: %TRUE if @name is valid, %FALSE otherwise.
+ *
+ **/
+gboolean
+ggit_ref_is_valid_name (const gchar *name)
+{
+	g_return_val_if_fail (name != NULL, FALSE);
+
+	return git_reference_is_valid_name (name) == 1;
+}
+
 /**
  * ggit_ref_get_target:
  * @ref: a #GgitRef.
@@ -128,6 +152,22 @@ ggit_ref_get_name (GgitRef *ref)
 	return git_reference_name (_ggit_native_get (ref));
 }
 
+/**
+ * ggit_ref_get_shorthand:
+ * @ref: a #GgitRef
+ *
+ * Gets the shorthand name of @ref.
+ *
+ * Returns: the shorthand name of a reference.
+ */
+const gchar *
+ggit_ref_get_shorthand (GgitRef *ref)
+{
+	g_return_val_if_fail (ref != NULL, NULL);
+
+	return git_reference_shorthand (_ggit_native_get (ref));
+}
+
 /**
  * ggit_ref_to_string:
  * @ref: a #GgitRef.
@@ -486,4 +526,55 @@ ggit_ref_delete_reflog (GgitRef  *ref,
 	}
 }
 
+/**
+ * ggit_ref_is_tag:
+ * @ref: a #GgitRef.
+ *
+ * Check whether the reference is a tag.
+ *
+ * Returns: %TRUE if the reference is a tag, %FALSE otherwise.
+ *
+ **/
+gboolean
+ggit_ref_is_tag (GgitRef *ref)
+{
+	g_return_val_if_fail (ref != NULL, FALSE);
+
+	return git_reference_is_tag (_ggit_native_get (ref));
+}
+
+/**
+ * ggit_ref_is_remote:
+ * @ref: a #GgitRef.
+ *
+ * Check whether the reference is a remote.
+ *
+ * Returns: %TRUE if the reference is a remote, %FALSE otherwise.
+ *
+ **/
+gboolean
+ggit_ref_is_remote (GgitRef *ref)
+{
+	g_return_val_if_fail (ref != NULL, FALSE);
+
+	return git_reference_is_remote (_ggit_native_get (ref));
+}
+
+/**
+ * ggit_ref_is_branch:
+ * @ref: a #GgitRef.
+ *
+ * Check whether the reference is a branch.
+ *
+ * Returns: %TRUE if the reference is a branch, %FALSE otherwise.
+ *
+ **/
+gboolean
+ggit_ref_is_branch (GgitRef *ref)
+{
+	g_return_val_if_fail (ref != NULL, FALSE);
+
+	return git_reference_is_branch (_ggit_native_get (ref));
+}
+
 /* ex:set ts=8 noet: */
