@@ -62,6 +62,8 @@ GType           ggit_ref_get_type           (void) G_GNUC_CONST;
 
 GgitRef        *_ggit_ref_wrap              (git_reference  *ref);
 
+gboolean        ggit_ref_is_valid_name      (const gchar    *name);
+
 GgitOId        *ggit_ref_get_target         (GgitRef        *ref);
 
 const gchar    *ggit_ref_get_symbolic_target(GgitRef        *ref);
@@ -69,6 +71,7 @@ const gchar    *ggit_ref_get_symbolic_target(GgitRef        *ref);
 GgitRefType     ggit_ref_get_reference_type (GgitRef        *ref);
 
 const gchar    *ggit_ref_get_name           (GgitRef        *ref);
+const gchar    *ggit_ref_get_shorthand      (GgitRef        *ref);
 const gchar    *ggit_ref_to_string          (GgitRef        *ref);
 
 GgitRef        *ggit_ref_resolve            (GgitRef        *ref,
@@ -103,6 +106,10 @@ GgitReflog     *ggit_ref_get_reflog         (GgitRef        *ref,
 void            ggit_ref_delete_reflog      (GgitRef        *ref,
                                              GError        **error);
 
+gboolean        ggit_ref_is_tag             (GgitRef        *ref);
+gboolean        ggit_ref_is_remote          (GgitRef        *ref);
+gboolean        ggit_ref_is_branch          (GgitRef        *ref);
+
 G_END_DECLS
 
 #endif /* __GGIT_REF_H__ */
