@@ -214,4 +214,7 @@ ASSERT_ENUM (GGIT_ATTRIBUTE_CHECK_INDEX_THEN_FILE, GIT_ATTR_CHECK_INDEX_THEN_FIL
 ASSERT_ENUM (GGIT_ATTRIBUTE_CHECK_INDEX_ONLY,      GIT_ATTR_CHECK_INDEX_ONLY);
 ASSERT_ENUM (GGIT_ATTRIBUTE_CHECK_NO_SYSTEM,       GIT_ATTR_CHECK_NO_SYSTEM);
 
+ASSERT_ENUM (GGIT_PACKBUILDER_STAGE_ADDING_OBJECTS, GIT_PACKBUILDER_ADDING_OBJECTS);
+ASSERT_ENUM (GGIT_PACKBUILDER_STAGE_DELTAFICATION, GIT_PACKBUILDER_DELTAFICATION);
+
 /* ex:set ts=8 noet: */
