@@ -151,6 +151,20 @@ typedef struct _GgitDiffOptions GgitDiffOptions;
  */
 typedef struct _GgitDiffSimilarityMetric GgitDiffSimilarityMetric;
 
+/**
+ * GgitBlame:
+ *
+ * Represents a blame.
+ */
+typedef struct _GgitBlame GgitBlame;
+
+/**
+ * GgitBlameHunk:
+ *
+ * Represents a blame hunk.
+ */
+typedef struct _GgitBlameHunk GgitBlameHunk;
+
 /**
  * GgitIndex:
  *
@@ -362,6 +376,13 @@ typedef struct _GgitTreeEntry GgitTreeEntry;
  */
 typedef struct _GgitTreeBuilder GgitTreeBuilder;
 
+/**
+ * GgitBlameOptions:
+ *
+ * Represents blame options.
+ */
+typedef struct _GgitBlameOptions GgitBlameOptions;
+
 /**
  * GgitBranchType:
  * @GGIT_BRANCH_LOCAL: specifies a local branch.
@@ -381,6 +402,19 @@ typedef enum
 	GGIT_CAP_HTTPS   = 1 << 1
 } GgitCapFlags;
 
+
+/**
+ * GgitBlameFlags:
+ * @GGIT_BLAME_NORMAL: Normal blame, the default.
+ * @GGIT_BLAME_TRACK_COPIES_SAME_FILE: Track lines that have moved within a file
+ *                                     (like git blame -M)
+ */
+typedef enum
+{
+	GGIT_BLAME_NORMAL                 = 0,
+	GGIT_BLAME_TRACK_COPIES_SAME_FILE = 1 << 0,
+} GgitBlameFlags;
+
 /**
  * GgitConfigLevel:
  * @GGIT_CONFIG_LEVEL_SYSTEM: System-wide configuration file.
@@ -878,6 +912,39 @@ typedef enum {
 	GGIT_STATUS_SHOW_WORKDIR_ONLY = 2
 } GgitStatusShow;
 
+/**
+ * GgitAttributeCheckFlags:
+ * @GGIT_ATTRIBUTE_CHECK_FILE_THEN_INDEX: check working directory, then index.
+ * @GGIT_ATTRIBUTE_CHECK_INDEX_THEN_FILE: check index, then working directory.
+ * @GGIT_ATTRIBUTE_CHECK_INDEX_ONLY: check only index.
+ * @GGIT_ATTRIBUTE_CHECK_NO_SYSTEM: ignore system wide attributes.
+ *
+ * Attribute check flags indicate the order in which to check for gitattributes.
+ * git core uses @GGIT_ATTRIBUTE_CHECK_FILE_THEN_INDEX for all operations,
+ * except on checkout, where it uses @GGIT_ATTRIBUTE_CHECK_INDEX_THEN_FILE.
+ *
+ */
+typedef enum
+{
+	GGIT_ATTRIBUTE_CHECK_FILE_THEN_INDEX = 0,
+	GGIT_ATTRIBUTE_CHECK_INDEX_THEN_FILE = 1 << 0,
+	GGIT_ATTRIBUTE_CHECK_INDEX_ONLY      = 1 << 1,
+	GGIT_ATTRIBUTE_CHECK_NO_SYSTEM       = 1 << 2,
+} GgitAttributeCheckFlags;
+
+/**
+ * GgitPackbuilderStage:
+ * @GGIT_PACKBUILDER_STAGE_ADDING_OBJECTS: adding objects.
+ * @GGIT_PACKBUILDER_STAGE_DELTAFICATION: deltafication.
+ *
+ * Valid stages for pack building.
+ */
+typedef enum
+{
+	GGIT_PACKBUILDER_STAGE_ADDING_OBJECTS = 0,
+	GGIT_PACKBUILDER_STAGE_DELTAFICATION  = 1
+} GgitPackbuilderStage;
+
 /**
  * GgitConfigCallback:
  * @entry: a #GgitConfigEntry.
